@@ -1,7 +1,7 @@
 ---------------------------------------------------------------------------
 -- @author Uli Schlachter
 -- @copyright 2010 Uli Schlachter
--- @release v3.5.5
+-- @release v3.5.6
 ---------------------------------------------------------------------------
 
 local wbase = require("wibox.widget.base")
@@ -46,6 +46,9 @@ end
 function systray:fit(width, height)
     local num_entries = capi.awesome.systray()
     local base = base_size
+    if num_entries == 0 then
+        return 0, 0
+    end
     if base == nil then
         if width < height then
             base = width
